@@ -20,10 +20,12 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: gMain.mli 1347 2007-06-20 07:40:34Z guesdon $ *)
+(* $Id$ *)
 
 (** Library initialization, main event loop, and events *)
 
+open Gtk
+
 (** @gtkdoc gtk gtk-General *)
 module Main : sig
   val init : ?setlocale:bool -> unit -> string
@@ -56,6 +58,13 @@ module Grab : sig
   val get_current : unit -> GObj.widget
 end
 
+module Event : sig
+  val get_current_time : unit -> int32     (** May return GDK_CURRENT_TIME *)
+  val get_current : unit -> GdkEvent.any       (** May raise Gpointer.Null *)
+  val get_widget : 'a Gdk.event -> widget obj  (** May raise Gpointer.Null *)
+  val propagate : [> `widget] obj -> 'a Gdk.event -> unit
+end
+
 module Rc : sig
   val add_default_file : string -> unit
 end
@@ -81,4 +90,13 @@ module Io : sig
     cond:condition list -> callback:(condition list -> bool) -> ?prio:int -> channel -> id
   val remove : id -> unit
   val read : channel -> buf:string -> pos:int -> len:int -> int
+  val read_chars : channel -> buf:string -> pos:int -> len:int -> int
+end
+
+module Gc_custom : sig
+  val set_speed : int -> unit
+    (** make the allocation of custom blocks contribute more or less to
+        the GC cycle. 0 means do nothing, 100 is as in lablgtk 2.18.3.
+        The default is 10. *)
+  val get_speed : unit -> int
 end
