@@ -20,7 +20,7 @@
 /*                                                                        */
 /**************************************************************************/
 
-/* $Id: ml_gtkmisc.c 1441 2009-01-13 08:45:16Z ben_99_9 $ */
+/* $Id$ */
 
 #include <gtk/gtk.h>
 #include <caml/mlvalues.h>
@@ -51,6 +51,7 @@ CAMLprim value ml_gtkmisc_init(value unit)
 #endif
         gtk_calendar_get_type() +
         gtk_drawing_area_get_type() +
+        gtk_curve_get_type() +
         gtk_misc_get_type() +
         gtk_arrow_get_type() +
         gtk_image_get_type() +
@@ -175,6 +176,36 @@ CAMLprim value ml_gtk_calendar_is_day_marked (value c, value d)
 #define GtkDrawingArea_val(val) check_cast(GTK_DRAWING_AREA,val)
 ML_3 (gtk_drawing_area_size, GtkDrawingArea_val, Int_val, Int_val, Unit)
 
+/* gtkcurve.h */
+#include <stdio.h>
+
+#define GtkCurve_val(val) check_cast(GTK_CURVE,val)
+ML_1 (gtk_curve_reset, GtkCurve_val, Unit)
+ML_2 (gtk_curve_set_gamma, GtkCurve_val, Float_val, Unit)
+value ml_gtk_curve_set_vector (value curve, value points)
+{
+  guint len = Wosize_val(points) / Double_wosize;
+  gfloat* vect = g_malloc(len * sizeof(gfloat));
+  int i;
+  for (i = 0; i < len; i++)
+    vect[i] = Double_field(points,i);
+  gtk_curve_set_vector(GtkCurve_val(curve), len, vect);
+  g_free(vect);
+  return Val_unit;
+}
+value ml_gtk_curve_get_vector (value curve, value vlen)
+{
+  int i, len = Int_val(vlen);
+  gfloat* vect = g_malloc(len * sizeof(gfloat));
+  value ret;
+  gtk_curve_get_vector(GtkCurve_val(curve), len, vect);
+  ret = caml_alloc(len*Double_wosize, Double_array_tag);
+  for (i = 0; i < len; i++)
+    Store_double_field(ret, i, vect[i]);
+  g_free(vect);
+  return ret;
+}
+
 /* gtkmisc.h */
 
 /* gtkarrow.h */
